==> fine-web-0.0.1-20220919.091035-231.jar: static/js/gen/gen.js <==
var editIndex =undefined;
var tablecolumns=$('#tablecolumns');
var hibernateSequences_datagrid =$('#hibernateSequences_datagrid');
$(function() {
	if($.cookie('gensrc')){
		$('#gensrc').textbox("setValue",$.cookie('gensrc'));
	}
	tablecolumns.datagrid({
		 singleSelect:true,
		 rownumbers:true,
		 columns:[[
			          {field:'fieldName',title:'实体类属性名',width:100},
			          {field:'fieldDbName',title:'字段名',width:100},
			          {field:'fieldType',title:'字段类型',width:80},
			          {field:'dataLength',title:'长度',width:40},
			          {field:'precision',title:'精度(小数点)',width:80},
			          {field:'nullable',title:'可空',width:40},
			          {field:'fieldTitle',title:'字段标题',width:120,
			        	  editor:{type:'textbox'}},
			          {field:'fieldDic',title:'数据字典',width:200,
			        		  formatter:function(value,rowData,index){
			        			  if(rowData.fieldDicText){
			        				  return rowData.fieldDicText;
			        			  }
			        			  return value;
			        		  },
			        		  editor:{type:'combobox',options:{
		                            url:ctx+"/dic/alldiccode",
		                            editable:true,
		                            limitToList:true
							 }}}
			          ]],
		 onClickCell:onClickCell,
		 onEndEdit:onEndEdit
	 });
	 
	 
	 hibernateSequences_datagrid.datagrid({
		fit : true,
		singleSelect:true,
		rownumbers:true,
		pagination:true,
		pageSize:100,
		url:ctx+'/gen/findHibernateSequences.action',
		columns:[[
		          {
		        	  field:'opt',
		        	  title:'更新',
		        	  width:40,
		        	  align:'center',
		        	  formatter:function(value,rowData,index){	//value表示字段的值,rowData行记录数据,index行索引
		        		  return '<div onclick="update(\''+rowData.SEQUENCE_NAME+'\',\''+rowData.MAX_ID+'\','+rowData.FLAG+')" class="icon-detail iconfont blue">&nbsp;</div>';
		        	  }},
		        	  {field:'SEQUENCE_NAME',title:'表名',width:300},
		        	  {field:'SEQUENCE_NEXT_HI_VALUE',align:'right',title:'序列值',width:150},
		        	  {field:'MAX_ID',title:'最大值',align:'right',width:150}
		        	  ]],
		rowStyler: function(index,row){
			if (row.FLAG){
				return 'background-color:red;color:#fff;';
			}
		}

	});
});

function endEditing(){
    if (!editIndex == undefined){return true}
    if (tablecolumns.datagrid('validateRow', editIndex)){
    	tablecolumns.datagrid('endEdit', editIndex);
        editIndex = undefined;
        return true;
    } else {
        return false;
    }
}

function onClickCell(index, field){
    if (editIndex != index){
        if (endEditing()){
        	tablecolumns.datagrid('beginEdit', index);
           // var ed = $('#dg').datagrid('getEditor', {index:index,field:field});
           // if (ed){
           //     ($(ed.target).data('textbox') ? $(ed.target).textbox('textbox') : $(ed.target)).focus();
           // }
            editIndex = index;
        } 
    }
}
function onEndEdit(index, row){
    var ed = $(this).datagrid('getEditor', {
        index: index,
        field: 'fieldDic'
    });
    row.fieldDicText = $(ed.target).combobox('getText');
}

function gogenerator(type){
	endEditing();
	var rows = tablecolumns.datagrid('getChanges');
		var effectRow = new Object();
		effectRow["rowlist"] = JSON.stringify(rows);
	 $('#gen_form').form('submit',{
		 dataType : 'json',
		 type : 'post',
		 url:ctx+"/gen/gensrc",
         onSubmit: function(param){
        	 var genobjs=new Array();  
        	 $('input[name="genobjs"]:checked').each(function(){  
        		 genobjs.push($(this).val());//向数组中添加元素  
        	 });
        	 if(genobjs.length==0){
        		 alertInfo("请选择要生成的对象");
          		return false;
        	 }
         	param.rowlist=JSON.stringify(rows);
         	param.type=type;
//         	if(!/^[a-zA-Z]:\\[a-zA-Z_0-9\u4e00-\u9fa5\\]*$/i.test($("#gensrc").textbox("getValue"))){
//         		alertInfo("不是有效的目录，注意斜杠为\\");
//         		return false;
//         	}
         	$.removeCookie("gensrc");
         	$.cookie("gensrc",$("#gensrc").textbox("getValue"),{expires:30});
//        	 if($(this).form('validate')){
//        		// 防止重复发送
//        		$('#saveBtn').linkbutton('disable');
             	return $(this).form('validate');
//        	 }else{
//        		 return false;
//        	 }
         },
         success : function(result) {
        	 result=jQuery.parseJSON(result);
			if (result.success) {
				alertInfo(result.msg);	
			}else{
				alertError(result.msg);
			}
			// 启用按钮
			$('#saveBtn').linkbutton('enable');
		}	
     });
}
function genwithprocess(){//有流程
	endEditing();
	var rows = tablecolumns.datagrid('getChanges');
	var effectRow = new Object();
	effectRow["rowlist"] = JSON.stringify(rows);
	$('#gen_form').form('submit',{
		dataType : 'json',
		type : 'post',
		url:ctx+"/gen/gensrc",
		onSubmit: function(param){
			param.rowlist=JSON.stringify(rows);
//        	 if($(this).form('validate')){
//        		// 防止重复发送
//        		$('#saveBtn').linkbutton('disable');
			return true;
//        	 }else{
//        		 return false;
//        	 }
		},
		success : function(result) {
			result=jQuery.parseJSON(result);
			if (result.success) {
				alertInfo(result.msg);	
			}else{
				alertError(result.msg);
			}
			// 启用按钮
			$('#saveprocessBtn').linkbutton('enable');
		}	
	});
}


function chooseTable(){
	openChooseDialog({
		title:'选择数据库表',
		contenturl:'/gen/alltable',
		width:400,
		height:500,
		okhandler:function(){
			var row=$("#alltable").datagrid('getSelected');
			if(row){
				$("#tablename").textbox("setValue",row.code);
				$("#menuName").textbox("setValue",row.name);
				loadtable();
				loadtableColumns(row.code);
				return true;
			}else{
				 alertInfo("请选择表名");
				 return false;
			}
		}
	});
	
}

function loadtable(){
	var tablename=$('#tablename').textbox('getValue');
	 if(!tablename){
		 alertInfo("请输入表名");
		 return;
	 }
	 $.ajax({
		type : "POST",
		cache : false,
		dataType : "json",
		url : ctx + "/gen/loadtable.action?tablename="+tablename,
		success : function(result) {
			if(result.success){
				$('#tablecolumns').datagrid('loadData',result.o);
			}else{
				alertError(result.msg);
			}
		}
	}); 
}

function loadtableColumns(tablename){
	$("#treeid").combobox('clear');
	$("#treepid").combobox('clear');
	$("#treetext").combobox('clear');
	$("#treeid").combobox('reload',ctx+"/gen/loadtablecolumns?tablename="+tablename);
	$("#treepid").combobox('reload',ctx+"/gen/loadtablecolumns?tablename="+tablename);
	$("#treetext").combobox('reload',ctx+"/gen/loadtablecolumns?tablename="+tablename);
}
	
function hiddenTreeConfig(){
$("#pagetype").val(0);
$("#treeconfig").hide();
$("#treeid").combobox({
			required : false
		});
$("#treepid").combobox({
			required : false
		});
$("#treetext").combobox({
			required : false
		});
}
function showTreeConfig(){
$("#pagetype").val(1);
$("#treeconfig").show();
$("#treeid").combobox({
			required : true
		});
$("#treepid").combobox({
			required : true
		});
$("#treetext").combobox({
			required : true
		});
}


function downloadfile(){
	downloadFile({
		versionid:$("#filechoose_text").textbox('getValue')
	});
}
function downloadfile2(){
	downloadFile({
		versionid:$("#filechoose_text2").textbox('getValue'),
		usebase:false
	});
}
function viewfile(){
	previewFile({
		versionid:$("#filechoose_text").textbox('getValue')
	})
	
}
function openbuildform() {
	var projectid;
	openSaveDialog({
		title:"自动生成表单",
		maximized:true,
		contenturl:"/GenForm/form?formcode=BFmContract_Form&projectid="+projectid,
		submiturl:"/GenForm/save"
	});
	
}

function searchfile(value){
	$.ajax({
		type : "POST",
		cache : false,
		dataType : "json",
		url : ctx + "/file/testsearch?search="+value,
		success : function(result) {
			if(result.success){
				alert(JSON.stringify(result.o))
			}	
		}
	}); 
}

function testscan(value){
	$.ajax({
		type : "POST",
		cache : false,
		dataType : "json",
		url : ctx + "/file/testscan?sessionid="+value,
		success : function(result) {
			if(result.success){
				alert(result.msg);
			}	
		}
	}); 
}

function opendetailform(){
var detailformcode=$("#detailformcode").val();
var detailpk=$("#detailpk").val();
	openDetailDialog({
		title : "查看记录",
		maximized : true,
		contenturl:"/GenForm/form?formcode="+detailformcode+"&isdetail=true&id="+detailpk
	});
}

function getAppform(){
var detailformcode=$("#detailformcode").val();
var detailpk=$("#detailpk").val();
$.ajax({
		type : "POST",
		cache : false,
		dataType : "json",
		url : ctx + "/GenForm/appform",
		data:{
			formcode:detailformcode,
			id:detailpk
		},
		success : function(result) {
			alert(JSON.stringify(result));
			console.log(result);
		}
	}); 
}

function genorgpinyin(){
	$.ajax({
		type : "POST",
		cache : false,
		dataType : "json",
		url : ctx + "/BasContactOrg/genBasContactOrgPinYin",
		success : function(result) {
			if(result.success){
				alert(result.msg);
			}	
		}
	}); 
}

function update(tableName,maxId,flag){
	if(flag){
		$.ajax({
			type:'post',
			dataType:'json',
			url:ctx+"/gen/updateHibernateSequences.action",
			data:{
				tableName:tableName,
				maxId:maxId
			},
			success : function(result) {
				if (result.success) {
					hibernateSequences_datagrid.datagrid('reload');
					alertInfo(result.msg);
				}else {
					alertError(result.msg);
				}
			},
			error : function() {
				alertError(result.msg);
			}
		});
	}else{
		alertInfo("该序列不需要更新");
	}
}

function chooseFlow(){
	openChooseDialog({
		title:'选择流程',
		contenturl:'/GenForm/allflow',
		width:400,
		height:500,
		okhandler:function(){
			var row=$("#allflow").datagrid('getSelected');
			if(row){
				$("#flowCode").val(row.value);
				$("#flowCode_TEXT_").textbox("setValue",row.text);
				return true;
			}else{
				 alertInfo("请选择流程");
				 return false;
			}
		}
	});
	
}

 //创建流程实例
  function createliuChengId(){
	  var liuchengId=$('#flowCode').val();
	  var accountid=$('#accountid').val();
	  var liuchengnum=$('#liuchengnum').val();
	  if(liuchengId){
		  $.ajax({
				type : "POST",
				cache : false,
				dataType : "json",
				url : ctx + "/gen/createLiuChengShili.action?liuchengId="+liuchengId+"&accountid="+accountid+"&liuchengnum="+liuchengnum,
				success : function(result) {
	              if(result.success){
	            	 $('#createliuChengIdValue').textbox('setValue',result.o);
	              }else{
	            	  alertError(result.msg);
	              }
					
				}
			}); 
	  }else{
		  alertInfo("请选择流程名称");

	  }
  }
  
  function viewflow(){
  	viewFlowDialog($("#processinitid").textbox('getValue'));
  
  }
  
  function doflow(){
  		$("#dolow_sendmessage").is(':checked');
 	 	var processinitid=$('#processinitid').val();
 	 	var dolow_formcode=$('#dolow_formcode').val();
 	 	var dolow_bizmainid=$('#dolow_bizmainid').val();
 	 	if(!processinitid){
 	 		 alertInfo("请输入流程id");
 	 	}
 	 	if(!dolow_formcode){
 	 		 alertInfo("表单编码");
 	 	}
  		openFlowDialog({
    		processInstId:processinitid,
			businessMainId:dolow_bizmainid,
			formCode:dolow_formcode,
			msgtitle:'测试'
        });
 }
 function deleteflowmsg(){
 	 var processinitid=$('#processinitid2').val();
	  if(processinitid){
		  $.ajax({
				type : "POST",
				cache : false,
				dataType : "json",
				url : ctx + "/wf/delMydealByProcessinstid.action?processinstid="+processinitid,
				success : function(result) {
	              if(result.success){
	            	 alertInfo(result.msg);
	              }else{
	            	  alertError(result.msg);
	              }
					
				}
			}); 
	  }else{
		  alertInfo("请输入流程id");

	  }
 }
 function formatterMod  (value,row){
 	return '<a class=" icon-edit iconfont green" href=\'javascript:modifyFlowPerson('+row.workitemid+','+row.accountId+','+row.msgId+',\"'+row.workitemname+'\",\"'+row.accountName+'\",\"'+row.processinstname+'\")\'></a>'
 }
 function modifyFlowPerson(workitemid,accountId,msgId,workitemname,accountName,flowCode){
		$("#newActId").combobox('reload',ctx+'/GenFormFlow/getFlowActs?type=comb&flowCode='+flowCode)
	 $("#accountName").html(accountName);
	 $("#workitemname").html(workitemname);
	 $('#modifyWin').dialog({
	        width: 480,
	        height: 260,
	        modal: true,
	        collapsible: false,
	        minimizable: false,
	        maximizable: false,
	        buttons: [{
	            text: '确定',
	            handler: function () {
	            	if(!$("#addPersons").val()&&!$("#newActId").combobox("getValue")){
	            		alertInfo("请选择接收人员或者新节点")
	            		return;
	            	}
	            	alertConfirmYes('您确认修改待办人员？', function(r) {
	            		if (r) {
	            			layer.msg('数据发送中', {icon: 16, shade: 0.3, time: 0});
	            			$.ajax({
	            				url : ctx + "/BasMessage/updateMsgAccount",
	            				data : {
	            					workitemid : workitemid
	            					,accountId : accountId
	            					,msgId:msgId
	            					,newaccountId : $("#addPersons").val()
									,newActId:$("#newActId").combobox("getValue")
									,newActName:$("#newActId").combobox("getText")
	            				},
	            				dataType : 'json',
	            				success : function(result) {
	            			    	 layer.closeAll();
	           		                 $('#modifyWin').dialog("close");
	            					if (result.success) {
	            						alertInfo(result.msg);
	            						queryflowmsg();
	            					} else {
	            						alertError(result.msg);
	            					}
	            				}
	            			});
	            		}
	            	});
	            }
	        }, {
	            text: '取消',
	            handler: function () {
	                $('#modifyWin').dialog("close");
	            }
	        }]
	    });
 }
 function queryflowmsg(){
 	 $("#todotable_datagrid").datagrid('load',{
 		processinstid:$('#processinitid3').val()
 	 })
 }
 function setcascadecomboboxValue(){
 	$("#cascadecombobox").cascadecombobox('setFullValue',48);
 }
 function setcascadecomboboxValue2(){
	 	console.info($("#cascadecombobox2"));
		$("input[typename='cascadecombobox2']").each(function(){
			console.info($(this));
			$(this).cascadecombobox('setFullValue',60);
		});
	 }
 function uploadfile(){
 	$("#fileuploadfrom").form('submit');
 }

==> fine-web-0.0.2-20220909.090829-172.jar: static/js/gen/gen.js <==
var editIndex =undefined;
var tablecolumns=$('#tablecolumns');
var hibernateSequences_datagrid =$('#hibernateSequences_datagrid');
var uSwitch='';
var verificationSwitch='';
$(function() {
	if($.cookie('gensrc')){
		$('#gensrc').textbox("setValue",$.cookie('gensrc'));
	}
	tablecolumns.datagrid({
		 singleSelect:true,
		 rownumbers:true,
		 columns:[[
			          {field:'fieldName',title:'实体类属性名',width:100},
			          {field:'fieldDbName',title:'字段名',width:100},
			          {field:'fieldType',title:'字段类型',width:80},
			          {field:'dataLength',title:'长度',width:40},
			          {field:'precision',title:'精度(小数点)',width:80},
			          {field:'nullable',title:'可空',width:40},
			          {field:'fieldTitle',title:'字段标题',width:120,
			        	  editor:{type:'textbox'}},
			          {field:'fieldDic',title:'数据字典',width:200,
			        		  formatter:function(value,rowData,index){
			        			  if(rowData.fieldDicText){
			        				  return rowData.fieldDicText;
			        			  }
			        			  return value;
			        		  },
			        		  editor:{type:'combobox',options:{
		                            url:ctx+"/dic/alldiccode",
		                            editable:true,
		                            limitToList:true
							 }}}
			          ]],
		 onClickCell:onClickCell,
		 onEndEdit:onEndEdit
	 });
	 
	 
	 hibernateSequences_datagrid.datagrid({
		fit : true,
		singleSelect:true,
		rownumbers:true,
		pagination:true,
		pageSize:100,
		url:ctx+'/gen/findHibernateSequences.action',
		columns:[[
		          {
		        	  field:'opt',
		        	  title:'更新',
		        	  width:40,
		        	  align:'center',
		        	  formatter:function(value,rowData,index){	//value表示字段的值,rowData行记录数据,index行索引
		        		  return '<div onclick="update(\''+rowData.SEQUENCE_NAME+'\',\''+rowData.MAX_ID+'\','+rowData.FLAG+')" class="icon-detail iconfont blue">&nbsp;</div>';
		        	  }},
		        	  {field:'SEQUENCE_NAME',title:'表名',width:300},
		        	  {field:'SEQUENCE_NEXT_HI_VALUE',align:'right',title:'序列值',width:150},
		        	  {field:'MAX_ID',title:'最大值',align:'right',width:150}
		        	  ]],
		rowStyler: function(index,row){
			if (row.FLAG){
				return 'background-color:red;color:#fff;';
			}
		}

	});
	 //获取AipOcrCilentUtils的静态常量值
	getAipOcr()
});

function getAipOcr() {
	//获取AipOcrCilentUtils的静态常量值
	$.ajax({
		url : ctx+"/PubOcrCilentController/getAipOcr",
		dataType : 'json',
		success : function(result) {
			$('#SWITCH_TEXT').html(result.SWITCH_TEXT);
			$('#SWITCH_UPDATE_TEXT').html(result.SWITCH_UPDATE_TEXT);
			uSwitch=result.SWITCH_UPDATE;
			$('#VERIFICATION_SWITCH_TEXT').html(result.VERIFICATION_SWITCH_TEXT);
			$('#VERIFICATION_SWITCH_UPDATE_TEXT').html(result.VERIFICATION_SWITCH_UPDATE_TEXT);
			verificationSwitch=result.VERIFICATION_SWITCH_UPDATE;

		}
	});
}


function updateSwitch() {
	$.ajax({
		url : ctx+"/PubOcrCilentController/updateSwitch",
		async:false,
		data:{
			uSwitch:uSwitch
		},
		dataType : 'json',
		success : function(result) {
			alertInfo(result.msg);
		}
	});
	getAipOcr();
}
function updateVerificationSwitch() {
	$.ajax({
		url : ctx+"/PubOcrCilentController/updateVerificationSwitch",
		async:false,
		data:{
			verificationSwitch:verificationSwitch
		},
		dataType : 'json',
		success : function(result) {
			alertInfo(result.msg);
		}
	});
	getAipOcr();
}


function endEditing(){
    if (!editIndex == undefined){return true}
    if (tablecolumns.datagrid('validateRow', editIndex)){
    	tablecolumns.datagrid('endEdit', editIndex);
        editIndex = undefined;
        return true;
    } else {
        return false;
    }
}

function onClickCell(index, field){
    if (editIndex != index){
        if (endEditing()){
        	tablecolumns.datagrid('beginEdit', index);
           // var ed = $('#dg').datagrid('getEditor', {index:index,field:field});
           // if (ed){
           //     ($(ed.target).data('textbox') ? $(ed.target).textbox('textbox') : $(ed.target)).focus();
           // }
            editIndex = index;
        } 
    }
}
function onEndEdit(index, row){
    var ed = $(this).datagrid('getEditor', {
        index: index,
        field: 'fieldDic'
    });
    row.fieldDicText = $(ed.target).combobox('getText');
}

function gogenerator(type){
	endEditing();
	var rows = tablecolumns.datagrid('getChanges');
		var effectRow = new Object();
		effectRow["rowlist"] = JSON.stringify(rows);
	 $('#gen_form').form('submit',{
		 dataType : 'json',
		 type : 'post',
		 url:ctx+"/gen/gensrc",
         onSubmit: function(param){
        	 var genobjs=new Array();  
        	 $('input[name="genobjs"]:checked').each(function(){  
        		 genobjs.push($(this).val());//向数组中添加元素  
        	 });
        	 if(genobjs.length==0){
        		 alertInfo("请选择要生成的对象");
          		return false;
        	 }
         	param.rowlist=JSON.stringify(rows);
         	param.type=type;
//         	if(!/^[a-zA-Z]:\\[a-zA-Z_0-9\u4e00-\u9fa5\\]*$/i.test($("#gensrc").textbox("getValue"))){
//         		alertInfo("不是有效的目录，注意斜杠为\\");
//         		return false;
//         	}
         	$.removeCookie("gensrc");
         	$.cookie("gensrc",$("#gensrc").textbox("getValue"),{expires:30});
//        	 if($(this).form('validate')){
//        		// 防止重复发送
//        		$('#saveBtn').linkbutton('disable');
             	return $(this).form('validate');
//        	 }else{
//        		 return false;
//        	 }
         },
         success : function(result) {
        	 result=jQuery.parseJSON(result);
			if (result.success) {
				alertInfo(result.msg);	
			}else{
				alertError(result.msg);
			}
			// 启用按钮
			$('#saveBtn').linkbutton('enable');
		}	
     });
}
function genwithprocess(){//有流程
	endEditing();
	var rows = tablecolumns.datagrid('getChanges');
	var effectRow = new Object();
	effectRow["rowlist"] = JSON.stringify(rows);
	$('#gen_form').form('submit',{
		dataType : 'json',
		type : 'post',
		url:ctx+"/gen/gensrc",
		onSubmit: function(param){
			param.rowlist=JSON.stringify(rows);
//        	 if($(this).form('validate')){
//        		// 防止重复发送
//        		$('#saveBtn').linkbutton('disable');
			return true;
//        	 }else{
//        		 return false;
//        	 }
		},
		success : function(result) {
			result=jQuery.parseJSON(result);
			if (result.success) {
				alertInfo(result.msg);	
			}else{
				alertError(result.msg);
			}
			// 启用按钮
			$('#saveprocessBtn').linkbutton('enable');
		}	
	});
}


function chooseTable(){
	openChooseDialog({
		title:'选择数据库表',
		contenturl:'/gen/alltable',
		width:400,
		height:500,
		okhandler:function(){
			var row=$("#alltable").datagrid('getSelected');
			if(row){
				$("#tablename").textbox("setValue",row.code);
				$("#menuName").textbox("setValue",row.name);
				loadtable();
				loadtableColumns(row.code);
				return true;
			}else{
				 alertInfo("请选择表名");
				 return false;
			}
		}
	});
	
}

function loadtable(){
	var tablename=$('#tablename').textbox('getValue');
	 if(!tablename){
		 alertInfo("请输入表名");
		 return;
	 }
	 $.ajax({
		type : "POST",
		cache : false,
		dataType : "json",
		url : ctx + "/gen/loadtable.action?tablename="+tablename,
		success : function(result) {
			if(result.success){
				$('#tablecolumns').datagrid('loadData',result.o);
			}else{
				alertError(result.msg);
			}
		}
	}); 
}

function loadtableColumns(tablename){
	$("#treeid").combobox('clear');
	$("#treepid").combobox('clear');
	$("#treetext").combobox('clear');
	$("#treeid").combobox('reload',ctx+"/gen/loadtablecolumns?tablename="+tablename);
	$("#treepid").combobox('reload',ctx+"/gen/loadtablecolumns?tablename="+tablename);
	$("#treetext").combobox('reload',ctx+"/gen/loadtablecolumns?tablename="+tablename);
}
	
function hiddenTreeConfig(){
$("#pagetype").val(0);
$("#treeconfig").hide();
$("#treeid").combobox({
			required : false
		});
$("#treepid").combobox({
			required : false
		});
$("#treetext").combobox({
			required : false
		});
}
function showTreeConfig(){
$("#pagetype").val(1);
$("#treeconfig").show();
$("#treeid").combobox({
			required : true
		});
$("#treepid").combobox({
			required : true
		});
$("#treetext").combobox({
			required : true
		});
}


function downloadfile(){
	downloadFile({
		versionid:$("#filechoose_text").textbox('getValue')
	});
}
function downloadfile2(){
	downloadFile({
		versionid:$("#filechoose_text2").textbox('getValue'),
		usebase:false
	});
}
function viewfile(){
	previewFile({
		versionid:$("#filechoose_text").textbox('getValue')
	})
	
}
function openbuildform() {
	var projectid;
	openSaveDialog({
		title:"自动生成表单",
		maximized:true,
		contenturl:"/GenForm/form?formcode=BFmContract_Form&projectid="+projectid,
		submiturl:"/GenForm/save"
	});
	
}

function searchfile(value){
	$.ajax({
		type : "POST",
		cache : false,
		dataType : "json",
		url : ctx + "/file/testsearch?search="+value,
		success : function(result) {
			if(result.success){
				alert(JSON.stringify(result.o))
			}	
		}
	}); 
}

function testscan(value){
	$.ajax({
		type : "POST",
		cache : false,
		dataType : "json",
		url : ctx + "/file/testscan?sessionid="+value,
		success : function(result) {
			if(result.success){
				alert(result.msg);
			}	
		}
	}); 
}

function opendetailform(){
var detailformcode=$("#detailformcode").val();
var detailpk=$("#detailpk").val();
	openDetailDialog({
		title : "查看记录",
		maximized : true,
		contenturl:"/GenForm/form?formcode="+detailformcode+"&isdetail=true&id="+detailpk
	});
}

function getAppform(){
var detailformcode=$("#detailformcode").val();
var detailpk=$("#detailpk").val();
$.ajax({
		type : "POST",
		cache : false,
		dataType : "json",
		url : ctx + "/GenForm/appform",
		data:{
			formcode:detailformcode,
			id:detailpk
		},
		success : function(result) {
			alert(JSON.stringify(result));
			console.log(result);
		}
	}); 
}

function genorgpinyin(){
	$.ajax({
		type : "POST",
		cache : false,
		dataType : "json",
		url : ctx + "/BasContactOrg/genBasContactOrgPinYin",
		success : function(result) {
			if(result.success){
				alert(result.msg);
			}	
		}
	}); 
}

function update(tableName,maxId,flag){
	if(flag){
		$.ajax({
			type:'post',
			dataType:'json',
			url:ctx+"/gen/updateHibernateSequences.action",
			data:{
				tableName:tableName,
				maxId:maxId
			},
			success : function(result) {
				if (result.success) {
					hibernateSequences_datagrid.datagrid('reload');
					alertInfo(result.msg);
				}else {
					alertError(result.msg);
				}
			},
			error : function() {
				alertError(result.msg);
			}
		});
	}else{
		alertInfo("该序列不需要更新");
	}
}

function chooseFlow(){
	openChooseDialog({
		title:'选择流程',
		contenturl:'/GenForm/allflow',
		width:400,
		height:500,
		okhandler:function(){
			var row=$("#allflow").datagrid('getSelected');
			if(row){
				$("#flowCode").val(row.value);
				$("#flowCode_TEXT_").textbox("setValue",row.text);
				return true;
			}else{
				 alertInfo("请选择流程");
				 return false;
			}
		}
	});
	
}

 //创建流程实例
  function createliuChengId(){
	  var liuchengId=$('#flowCode').val();
	  var accountid=$('#accountid').val();
	  var liuchengnum=$('#liuchengnum').val();
	  if(liuchengId){
		  $.ajax({
				type : "POST",
				cache : false,
				dataType : "json",
				url : ctx + "/gen/createLiuChengShili.action?liuchengId="+liuchengId+"&accountid="+accountid+"&liuchengnum="+liuchengnum,
				success : function(result) {
	              if(result.success){
	            	 $('#createliuChengIdValue').textbox('setValue',result.o);
	              }else{
	            	  alertError(result.msg);
	              }
					
				}
			}); 
	  }else{
		  alertInfo("请选择流程名称");

	  }
  }
  
  function viewflow(){
  	viewFlowDialog($("#processinitid").textbox('getValue'));
  
  }
  
  function doflow(){
  		$("#dolow_sendmessage").is(':checked');
 	 	var processinitid=$('#processinitid').val();
 	 	var dolow_formcode=$('#dolow_formcode').val();
 	 	var dolow_bizmainid=$('#dolow_bizmainid').val();
 	 	if(!processinitid){
 	 		 alertInfo("请输入流程id");
 	 	}
 	 	if(!dolow_formcode){
 	 		 alertInfo("表单编码");
 	 	}
  		openFlowDialog({
    		processInstId:processinitid,
			businessMainId:dolow_bizmainid,
			formCode:dolow_formcode,
			msgtitle:'测试'
        });
 }
 function deleteflowmsg(){
 	 var processinitid=$('#processinitid2').val();
	  if(processinitid){
		  $.ajax({
				type : "POST",
				cache : false,
				dataType : "json",
				url : ctx + "/wf/delMydealByProcessinstid.action?processinstid="+processinitid,
				success : function(result) {
	              if(result.success){
	            	 alertInfo(result.msg);
	              }else{
	            	  alertError(result.msg);
	              }
					
				}
			}); 
	  }else{
		  alertInfo("请输入流程id");

	  }
 }
 function formatterMod  (value,row){
 	return '<a class=" icon-edit iconfont green" href=\'javascript:modifyFlowPerson('+row.workitemid+','+row.accountId+','+row.msgId+',\"'+row.workitemname+'\",\"'+row.accountName+'\",\"'+row.processinstname+'\")\'></a>'
 }
 function modifyFlowPerson(workitemid,accountId,msgId,workitemname,accountName,flowCode){
		$("#newActId").combobox('reload',ctx+'/GenFormFlow/getFlowActs?type=comb&flowCode='+flowCode)
	 $("#accountName").html(accountName);
	 $("#workitemname").html(workitemname);
	 $('#modifyWin').dialog({
	        width: 480,
	        height: 260,
	        modal: true,
	        collapsible: false,
	        minimizable: false,
	        maximizable: false,
	        buttons: [{
	            text: '确定',
	            handler: function () {
	            	if(!$("#addPersons").val()&&!$("#newActId").combobox("getValue")){
	            		alertInfo("请选择接收人员或者新节点")
	            		return;
	            	}
	            	alertConfirmYes('您确认修改待办人员？', function(r) {
	            		if (r) {
	            			layer.msg('数据发送中', {icon: 16, shade: 0.3, time: 0});
	            			$.ajax({
	            				url : ctx + "/BasMessage/updateMsgAccount",
	            				data : {
	            					workitemid : workitemid
	            					,accountId : accountId
	            					,msgId:msgId
	            					,newaccountId : $("#addPersons").val()
									,newActId:$("#newActId").combobox("getValue")
									,newActName:$("#newActId").combobox("getText")
	            				},
	            				dataType : 'json',
	            				success : function(result) {
	            			    	 layer.closeAll();
	           		                 $('#modifyWin').dialog("close");
	            					if (result.success) {
	            						alertInfo(result.msg);
	            						queryflowmsg();
	            					} else {
	            						alertError(result.msg);
	            					}
	            				}
	            			});
	            		}
	            	});
	            }
	        }, {
	            text: '取消',
	            handler: function () {
	                $('#modifyWin').dialog("close");
	            }
	        }]
	    });
 }
 function queryflowmsg(){
 	 $("#todotable_datagrid").datagrid('load',{
 		processinstid:$('#processinitid3').val()
 	 })
 }
 function setcascadecomboboxValue(){
 	$("#cascadecombobox").cascadecombobox('setFullValue',48);
 }
 function setcascadecomboboxValue2(){
	 	console.info($("#cascadecombobox2"));
		$("input[typename='cascadecombobox2']").each(function(){
			console.info($(this));
			$(this).cascadecombobox('setFullValue',60);
		});
	 }
 function uploadfile(){
 	$("#fileuploadfrom").form('submit');
 }
